'**************************************************************************
'*      MSSetup Toolkit Quix Installation
'**************************************************************************

'$DEFINE DEBUG  ''Define for script development/debugging

'$INCLUDE 'setupapi.inc'
'$INCLUDE 'msdetect.inc'

''Dialog ID's
CONST WELCOME       = 100
CONST ASKQUIT       = 200
CONST DESTPATH      = 300
CONST EXITFAILURE   = 400
CONST EXITQUIT      = 600
CONST EXITSUCCESS   = 700
CONST OPTIONS       = 800
CONST APPHELP       = 900
CONST BADPATH       = 6400

''Bitmap ID
CONST LOGO = 1

GLOBAL DEST$        ''Default destination directory.
GLOBAL OPTCUR$      ''Option selection from option dialog.

DECLARE SUB Install
DECLARE FUNCTION MakePath (szDir$, szFile$) AS STRING


INIT:
    CUIDLL$ = "mscuistf.dll"            ''Custom user interface dll
    HELPPROC$ = "FHelpDlgProc"          ''Help dialog procedure

    SetBitmap CUIDLL$, LOGO
    SetTitle "Quix Setup"

    szInf$ = GetSymbolValue("STF_SRCINFPATH")
    IF szInf$ = "" THEN
        szInf$ = GetSymbolValue("STF_CWDDIR") + "SETUP.INF"
    END IF
    ReadInfFile szInf$

    OPTCUR$ = "1"
    DEST$ = "C:\QUIX"

'$IFDEF DEBUG
    i% = SetSizeCheckMode(scmOnIgnore)    '' could use scmOff; def = scmOnFatal
    WinDrive$ = MID$(GetWindowsDir, 1, 1)
    IF IsDriveValid(WinDrive$) = 0 THEN
        i% = DoMsgBox("Das Windows-Laufwerk ('"+WinDrive$+"') ist ungltig !.", "Setup Meldung", MB_TASKMODAL+MB_ICONHAND+MB_OK)
        GOTO QUIT
    END IF
'$ENDIF ''DEBUG


WELCOME:
    sz$ = UIStartDlg(CUIDLL$, WELCOME, "FInfoDlgProc", APPHELP, HELPPROC$)
    IF sz$ = "CONTINUE" THEN
        UIPop 1
    ELSE
        GOSUB ASKQUIT
        GOTO WELCOME
    END IF


GETPATH:
    SetSymbolValue "EditTextIn", DEST$
    SetSymbolValue "EditFocus", "END"
GETPATHL1:
    sz$ = UIStartDlg(CUIDLL$, DESTPATH, "FEditDlgProc", APPHELP, HELPPROC$)
    DEST$ = GetSymbolValue("EditTextOut")

    IF sz$ = "CONTINUE" THEN
        IF IsDirWritable(DEST$) = 0 THEN
            GOSUB BADPATH
            GOTO GETPATHL1
        END IF
        UIPop 1
    ELSEIF sz$ = "REACTIVATE" THEN
        GOTO GETPATHL1
    ELSEIF sz$ = "BACK" THEN
        UIPop 1
        GOTO WELCOME
    ELSE
        GOSUB ASKQUIT
        GOTO WELCOME
    END IF


CHECKVBX:
    ''Check for duplicate VBX files in Windows directory
    IF DoesFileExist(GetWindowsDir + "msmasked.vbx", femExists) <> 0 THEN
      i% = DoMsgBox("Die Datei MSMASKED.VBX existiert bereits in Ihrem Windows-Verzeichnis !", "Setup Warnung", MB_TASKMODAL+MB_ICONHAND+MB_OK)
    END IF
    IF DoesFileExist(GetWindowsDir + "spin.vbx", femExists) <> 0 THEN
      i% = DoMsgBox("Die Datei SPIN.VBX existiert bereits in Ihrem Windows-Verzeichnis !", "Setup Warnung", MB_TASKMODAL+MB_ICONHAND+MB_OK)
    END IF
    IF DoesFileExist(GetWindowsDir + "threed.vbx", femExists) <> 0 THEN
      i% = DoMsgBox("Die Datei THREED.VBX existiert bereits in Ihrem Windows-Verzeichnis !", "Setup Warnung", MB_TASKMODAL+MB_ICONHAND+MB_OK)
    END IF
    
DOINSTALL:
    Install


QUIT:
    ON ERROR GOTO ERRQUIT

    IF ERR = 0 THEN
        dlg% = EXITSUCCESS
    ELSEIF ERR = STFQUIT THEN
        dlg% = EXITQUIT
    ELSE
        dlg% = EXITFAILURE
    END IF
QUITL1:
    sz$ = UIStartDlg(CUIDLL$, dlg%, "FInfo0DlgProc", 0, "")
    IF sz$ = "REACTIVATE" THEN
        GOTO QUITL1
    END IF
    UIPop 1

    END

ERRQUIT:
    i% = DoMsgBox("Das Setup-Programm ist defekt - bitte wenden Sie sich an den Hersteller !", "Setup Meldung", MB_OK+MB_TASKMODAL+MB_ICONHAND)
    END



BADPATH:
    sz$ = UIStartDlg(CUIDLL$, BADPATH, "FInfo0DlgProc", 0, "")
    IF sz$ = "REACTIVATE" THEN
        GOTO BADPATH
    END IF
    UIPop 1
    RETURN



ASKQUIT:
    sz$ = UIStartDlg(CUIDLL$, ASKQUIT, "FQuitDlgProc", 0, "")

    IF sz$ = "EXIT" THEN
        UIPopAll
        ERROR STFQUIT
    ELSEIF sz$ = "REACTIVATE" THEN
        GOTO ASKQUIT
    ELSE
        UIPop 1
    END IF
    RETURN



'**
'** Purpose:
'**     Builds the copy list and performs all installation operations.
'** Arguments:
'**     none.
'** Returns:
'**     none.
'*************************************************************************
SUB Install STATIC

    SrcDir$ = GetSymbolValue("STF_SRCDIR")
    CreateDir DEST$, cmoNone

    AddSectionFilesToCopyList "Files", SrcDir$, DEST$
    WINSYS$ = GetWindowsSysDir()
    WIN$ = GetWindowsDir()

    AddSectionFilesToCopyList "SystemFiles", SrcDir$, WINSYS$
    AddSectionFilesToCopyList "WindowsFiles", SrcDir$, WIN$
    CopyFilesInCopyList

    CreateProgmanGroup "Quix", "", cmoNone
    ShowProgmanGroup  "Quix", 1, cmoNone
    CreateProgmanItem "Quix", "Quix", MakePath(DEST$,"Quix.exe"), "", cmoOverwrite
    CreateProgmanItem "Quix", "Quix Hilfe", MakePath(DEST$,"Quix.hlp"), "", cmoOverwrite
    CreateProgmanItem "Quix", "Neueste Informationen", MakePath(DEST$,"News.hlp"), "", cmoOverwrite

END SUB



'**
'** Purpose:
'**     Appends a file name to the end of a directory path,
'**     inserting a backslash character as needed.
'** Arguments:
'**     szDir$  - full directory path (with optional ending "\")
'**     szFile$ - filename to append to directory
'** Returns:
'**     Resulting fully qualified path name.
'*************************************************************************
FUNCTION MakePath (szDir$, szFile$) STATIC AS STRING
    IF szDir$ = "" THEN
        MakePath = szFile$
    ELSEIF szFile$ = "" THEN
        MakePath = szDir$
    ELSEIF MID$(szDir$, LEN(szDir$), 1) = "\" THEN
        MakePath = szDir$ + szFile$
    ELSE
        MakePath = szDir$ + "\" + szFile$
    END IF
END FUNCTION
